@@ -4,11 +4,13 @@ import urllib.parse
 from typing import Any, Dict, Optional
 
 import inquirer
-import requests
 import pandas as pd
+import requests
 
 from .exceptions import AuthError, ConfigError
 
+SUCCESS_CODES = [200, 201, 202]
+
 
 class Metabasic(object):
     """Instantiates a new Metabasic Client
@@ -43,7 +45,7 @@ class Metabasic(object):
         Returns:
             (List[List[Any]]): The results of the query.
         """
-        resp = self.raw_query(query, export_format='json')
+        resp = self.raw_query(query, export_format="json")
         return resp.json()
 
     def raw_query(self, query: str, export_format: str) -> requests.Response:
@@ -83,7 +85,7 @@ class Metabasic(object):
             f"{self.domain}/api/dataset/{export_format}", data=data, headers=headers
         )
 
-        if resp.status_code != 202:
+        if resp.status_code not in SUCCESS_CODES:
             raise Exception(resp)
 
         return resp
@@ -100,7 +102,7 @@ class Metabasic(object):
         # Request csv export format so that don't lose the column order as specified
         # in the query. The json format does not always return the results in order,
         # and simple '/api/dataset/' requests do not return more than 2000 rows.
-        res = self.raw_query(query, export_format='csv')
+        res = self.raw_query(query, export_format="csv")
         buffer = io.BytesIO(res.content)
         df = pd.read_csv(buffer)
         return df
@@ -119,7 +121,7 @@ class Metabasic(object):
         body = {"username": email, "password": password}
         resp = requests.post(f"{self.domain}/api/session", json=body, headers=headers)
 
-        if resp.status_code != 200:
+        if resp.status_code not in SUCCESS_CODES:
             raise Exception(resp)
 
         self.session_id = resp.json()["id"]
@@ -142,7 +144,7 @@ class Metabasic(object):
 
         resp = requests.get(f"{self.domain}/api/database", headers=headers)
 
-        if resp.status_code != 200:
+        if resp.status_code not in SUCCESS_CODES:
             raise Exception(resp)
 
         databases = {db["name"]: db["id"] for db in resp.json()}
